topics.Topic (Topic) — amici1

# `topics.Topic` (Topic)

Topic(id, ref, name, description_text, description_text_de, description_text_fr, name_de, name_fr)

Master tables : topics.AllTopics (Topics), topics.Topics (Topics)

Slave tables : topics.InterestsByTopic (Interests)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Reference (ref) : The reference.

- Designation (name) : The designation in different languages.

- Long description (description_text) : Rich text field for a longer multi-line description.

- Long description (de) (description_text_de) : See `<lino.core.fields.RichTextField: description_text_de>`.

- Long description (fr) (description_text_fr) : See `<lino.core.fields.RichTextField: description_text_fr>`.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Description (description) : Virtual field which includes the formatted structured reference and the description_text.

- Name (name_column) : See `lino_xl.lib.topics.models.Topic.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.topics.models.Topic.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.topics.models.Topic.overview`.

Referenced from topics.Interest.topic

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
ref | Reference | The reference.
name | Designation | The designation in different languages.
description_text | Long description | Rich text field for a longer multi-line description.
description_text_de | Long description (de) |
description_text_fr | Long description (fr) |
name_de | Designation (de) |
name_fr | Designation (fr) |
description | Description | Virtual field which includes the formatted structured reference and the description_text.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |